#! /usr/bin/env python3
"""Test deployment and functionality of etckeeper charm."""

import unittest

import zaza.model


class TestBase(unittest.TestCase):
    """Base class for functional charm tests."""

    @classmethod
    def setUpClass(cls):
        """Run setup for tests."""
        cls.model_name = zaza.model.get_juju_model()
        cls.application_name = "etckeeper"


class EtckeeperTests(TestBase):
    """Test etckeeper charm."""

    def _assert_stdout_equals(self, expected, res):
        stdout = res.get("Stdout", "")
        stderr = res.get("Stderr", "")
        msg = "Mismatch.\nStdout: {}\nStderr: {}".format(stdout, stderr)
        self.assertTrue(expected in stdout.strip(), msg=msg)

    def test01_run_commit_action(self):
        """Test the commit action."""
        try:
            zaza.model.run_action_on_leader(
                self.application_name, "commit", raise_on_failure=True
            )
        except zaza.model.ActionFailed as e:
            self.fail("Commit action failed with {}".format(e))

    def test02_git_repo(self):
        """Test that the git repo is created."""
        results = zaza.model.run_on_leader(
            self.application_name, "ls -l /etc/.git/index", timeout=300
        )
        self._assert_stdout_equals("-rw-r--r-- 1 root root", results)
